==> openapi-rapi-domain-0.0.188-sources.jar: com/xforceplus/openapirapi/metadata/PageMeta.java <==
package com.xforceplus.openapirapi.metadata;

/**
 *
 * @author ultraman
 * @since 2023-04-19
 */

public class PageMeta {
    public interface Tasklist {
        static String code() {
            return "tasklist";
        }
        static String name() {
            return "任务列表";
        }
    }
    public interface MessageHistory {
        static String code() {
            return "messageHistory";
        }
        static String name() {
            return "消息履历";
        }
    }
    public interface TaxMessageStatistics {
        static String code() {
            return "taxMessageStatistics";
        }
        static String name() {
            return "税号消息统计";
        }
    }
    public interface AggregatedPurchaseInvoicePage {
        static String code() {
            return "aggregatedPurchaseInvoicePage";
        }
        static String name() {
            return "聚合进项发票页面";
        }
    }
    public interface 过滤进项发票页面 {
        static String code() {
            return "过滤进项发票页面";
        }
        static String name() {
            return "过滤进项发票页面";
        }
    }
    public interface InvoiceHistory {
        static String code() {
            return "invoiceHistory";
        }
        static String name() {
            return "发票履历页面";
        }
    }
    public interface NonVatInvoicePage {
        static String code() {
            return "nonVatInvoicePage";
        }
        static String name() {
            return "聚合非增票页面";
        }
    }
    public interface FilterNonVatInvoicePage {
        static String code() {
            return "filterNonVatInvoicePage";
        }
        static String name() {
            return "过滤非增票页面";
        }
    }
    public interface ForConfig {
        static String code() {
            return "forConfig";
        }
        static String name() {
            return "工作流配置专用";
        }
    }
    public interface AggregatedSalesInvoicePage {
        static String code() {
            return "aggregatedSalesInvoicePage";
        }
        static String name() {
            return "聚合销项发票页面";
        }
    }
    public interface FilterSalesInvoicePage {
        static String code() {
            return "filterSalesInvoicePage";
        }
        static String name() {
            return "过滤销项发票页面";
        }
    }
    public interface FailInvoiceMessagePage {
        static String code() {
            return "failInvoiceMessagePage";
        }
        static String name() {
            return "发票消息处理失败页面";
        }
    }
    public interface InvoiceSendStatisticPage {
        static String code() {
            return "invoiceSendStatisticPage";
        }
        static String name() {
            return "发票推送统计页面";
        }
    }
    public interface AsyncTaskPage {
        static String code() {
            return "asyncTaskPage";
        }
        static String name() {
            return "接口聚合任务查看页面";
        }
    }
    public interface InvoiceStatisticCompanyInfoPage {
        static String code() {
            return "invoiceStatisticCompanyInfoPage";
        }
        static String name() {
            return "租户发票推送配置页面";
        }
    }
    public interface FilterInvoiceConditionConfigPage {
        static String code() {
            return "filterInvoiceConditionConfigPage";
        }
        static String name() {
            return "发票过滤规则配置页面";
        }
    }
}

==> openapi-rapi-domain-0.0.276-sources.jar: com/xforceplus/openapirapi/metadata/PageMeta.java <==
package com.xforceplus.openapirapi.metadata;

/**
 *
 * @author ultraman
 * @since 2023-07-13
 */

public class PageMeta {
    public interface Tasklist {
        static String code() {
            return "tasklist";
        }
        static String name() {
            return "任务列表";
        }
    }
    public interface MessageHistory {
        static String code() {
            return "messageHistory";
        }
        static String name() {
            return "消息履历";
        }
    }
    public interface TaxMessageStatistics {
        static String code() {
            return "taxMessageStatistics";
        }
        static String name() {
            return "税号消息统计";
        }
    }
    public interface AggregatedPurchaseInvoicePage {
        static String code() {
            return "aggregatedPurchaseInvoicePage";
        }
        static String name() {
            return "聚合进项发票页面";
        }
    }
    public interface 过滤进项发票页面 {
        static String code() {
            return "过滤进项发票页面";
        }
        static String name() {
            return "过滤进项发票页面";
        }
    }
    public interface InvoiceHistory {
        static String code() {
            return "invoiceHistory";
        }
        static String name() {
            return "发票履历页面";
        }
    }
    public interface NonVatInvoicePage {
        static String code() {
            return "nonVatInvoicePage";
        }
        static String name() {
            return "聚合非增票页面";
        }
    }
    public interface FilterNonVatInvoicePage {
        static String code() {
            return "filterNonVatInvoicePage";
        }
        static String name() {
            return "过滤非增票页面";
        }
    }
    public interface ForConfig {
        static String code() {
            return "forConfig";
        }
        static String name() {
            return "工作流配置专用";
        }
    }
    public interface AggregatedSalesInvoicePage {
        static String code() {
            return "aggregatedSalesInvoicePage";
        }
        static String name() {
            return "聚合销项发票页面";
        }
    }
    public interface FilterSalesInvoicePage {
        static String code() {
            return "filterSalesInvoicePage";
        }
        static String name() {
            return "过滤销项发票页面";
        }
    }
    public interface FailInvoiceMessagePage {
        static String code() {
            return "failInvoiceMessagePage";
        }
        static String name() {
            return "发票消息处理失败页面";
        }
    }
    public interface InvoiceSendStatisticPage {
        static String code() {
            return "invoiceSendStatisticPage";
        }
        static String name() {
            return "发票推送统计页面";
        }
    }
    public interface AsyncTaskPage {
        static String code() {
            return "asyncTaskPage";
        }
        static String name() {
            return "接口聚合任务查看页面";
        }
    }
    public interface InvoiceStatisticCompanyInfoPage {
        static String code() {
            return "invoiceStatisticCompanyInfoPage";
        }
        static String name() {
            return "租户发票推送配置页面";
        }
    }
    public interface FilterInvoiceConditionConfigPage {
        static String code() {
            return "filterInvoiceConditionConfigPage";
        }
        static String name() {
            return "发票过滤规则配置页面";
        }
    }
    public interface InvoiceSendStatisticUserPage {
        static String code() {
            return "invoiceSendStatisticUserPage";
        }
        static String name() {
            return "纳税申报数据比对";
        }
    }
    public interface UserInvoiceStatisticPage {
        static String code() {
            return "userInvoiceStatisticPage";
        }
        static String name() {
            return "用户对账";
        }
    }
}
